package com.community.pocket.ui.main.ui.forum.main;

import android.os.Build;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.core.widget.NestedScrollView;
import androidx.lifecycle.Observer;
import androidx.lifecycle.ViewModelProvider;
import androidx.viewpager2.widget.ViewPager2;

import com.community.pocket.R;
import com.community.pocket.data.adapter.NoticeAdpter;
import com.community.pocket.data.model.Notice;
import com.community.pocket.ui.main.MainFragment;
import com.community.pocket.ui.main.ui.share.Response;

import org.xutils.view.annotation.ContentView;
import org.xutils.view.annotation.Event;
import org.xutils.view.annotation.ViewInject;

import java.util.List;

/**
 * 论坛框架
 */
@ContentView(R.layout.forum)
public class ForumFragment extends MainFragment {

    @ViewInject(R.id.paper)
    private ViewPager2 viewPager2;

    @ViewInject(R.id.scroll_body)
    private NestedScrollView nestedScrollView;

    @ViewInject(R.id.forum_new)
    private Button newButton;

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        ForumViewModel viewModel = new ViewModelProvider(this, new ViewModelProvider.NewInstanceFactory()).get(ForumViewModel.class);

        viewModel.loadNotice();

        newButton.setOnClickListener(new View.OnClickListener() {
            @RequiresApi(api = Build.VERSION_CODES.KITKAT)
            @Override
            public void onClick(View v) {
                _new(v);
            }
        });

        //监控公告信息请求状态
        viewModel.getNoticeDataResponse().observe(getViewLifecycleOwner(), new Observer<ForumNoticeResponse>() {
            @Override
            public void onChanged(ForumNoticeResponse forumNoticeResponse) {
                if (forumNoticeResponse == null) {
                    return;
                }

                forumNoticeResponse.toast(getContext());

                if (forumNoticeResponse.getResult() == Response.Result.OK) {
                    initNotice(forumNoticeResponse.getNoticeList());
                }
            }
        });
    }

    //加载公告信息
    private void initNotice(List<Notice> notices) {
        viewPager2.setAdapter(new NoticeAdpter(notices));
    }

    private void scrollTop() {
        nestedScrollView.fling(0);
        nestedScrollView.smoothScrollTo(0, 0);
    }
    
    //跳转热榜界面
    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    @Event(value = R.id.forum_hot)
    private void hot(View view) {
        scrollTop();
        ctrl().navigate(R.id.forumHotFragment);
        changeColor(view);
    }

    //跳转最新界面
    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void _new(View view) {
        scrollTop();
        ctrl().navigate(R.id.forumNewFragment);
        changeColor(view);
    }


    //跳转发帖界面
    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    @Event(value = R.id.forum_post)
    private void post(View view) {
        scrollTop();
        ctrl().navigate(R.id.forumPostFragment);
        changeColor(view);
    }

    //跳转我的帖子界面
    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    @Event(value = R.id.forum_my)
    private void my(View view) {
        scrollTop();
        ctrl().navigate(R.id.forumMyFragment);
        changeColor(view);
    }

    @Override
    protected int fragmentId() {
        return R.id.fragment;
    }

    @Override
    protected int[] button_ids() {
        return new int[]{R.id.forum_hot, R.id.forum_new, R.id.forum_post, R.id.forum_my};
    }
}
